==> aroundme_0_5_1.zip: aroundme_0_5_1/aroundme/language/1/barnraiser_01/arrays/arr_group.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of aroundme
//
// Copyright (C) 2003, 2005 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
// 02111-1307, USA.
// -----------------------------------------------------------------------
// Tom Calthrop - 20th April 2004 (tom@barnraiser.org)



// MEMBERSHIP STATISTICS -------------------------------------------------
$lang['arr_group_member_statistic_type_id'][301] = 		"total blogs";
$lang['arr_group_member_statistic_type_id'][302] = 		"total comments";
$lang['arr_group_member_statistic_type_id'][303] = 		"total discussions";
$lang['arr_group_member_statistic_type_id'][304] = 		"total wiki pages";
$lang['arr_group_member_statistic_type_id'][305] = 		"total polls";


// GROUP STATISTICS ------------------------------------------------------
$lang['arr_group_statistic_type_id'][101] = 			"total members";
$lang['arr_group_statistic_type_id'][102] = 			"total discussions";
$lang['arr_group_statistic_type_id'][103] = 			"total comments";
$lang['arr_group_statistic_type_id'][104] = 			"total wiki pages";
$lang['arr_group_statistic_type_id'][105] = 			"total polls";
$lang['arr_group_statistic_type_id'][106] = 			"total blogs";


// REGISTRATION TYPE -----------------------------------------------------
$lang['arr_registration_type'][1] = 					"automatic";
$lang['arr_registration_type'][2] = 					"approved";
$lang['arr_registration_type'][3] = 					"closed";


// GROUP MEMBER STATUS ---------------------------------------------------
$lang['arr_group_member_status'][1] = 					"barred";
$lang['arr_group_member_status'][2] = 					"pending";
$lang['arr_group_member_status'][3] = 					"active";


// GROUP MEMBER STATUS ---------------------------------------------------
$lang['arr_group_status'][1] = 							"inactive";
$lang['arr_group_status'][2] = 							"hold";
$lang['arr_group_status'][3] = 							"pending";
$lang['arr_group_status'][4] = 							"active";


// GROUP VISIBILITY ---------------------------------------------------
$lang['arr_group_visibility'][1] = 						"visible";
$lang['arr_group_visibility'][2] = 						"hidden";

?>

==> aroundme_0_6_1.zip: aroundme_0_6_1/aroundme/language/1/barnraiser_01/arrays/arr_group.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of AROUNDMe
//
// Copyright (C) 2003 - 2006 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------
// Tom Calthrop - 20th April 2004 (tom@barnraiser.org)



// MEMBERSHIP STATISTICS -------------------------------------------------
$lang['arr_group_member_statistic_type_id'][301] = 		"total blogs";
$lang['arr_group_member_statistic_type_id'][302] = 		"total comments";
$lang['arr_group_member_statistic_type_id'][303] = 		"total discussions";
$lang['arr_group_member_statistic_type_id'][304] = 		"total wiki pages";
$lang['arr_group_member_statistic_type_id'][305] = 		"total polls";
$lang['arr_group_member_statistic_type_id'][306] = 		"total schedule items";


// GROUP STATISTICS ------------------------------------------------------
$lang['arr_group_statistic_type_id'][101] = 			"total members";
$lang['arr_group_statistic_type_id'][102] = 			"total discussions";
$lang['arr_group_statistic_type_id'][103] = 			"total comments";
$lang['arr_group_statistic_type_id'][104] = 			"total wiki pages";
$lang['arr_group_statistic_type_id'][105] = 			"total polls";
$lang['arr_group_statistic_type_id'][106] = 			"total blogs";
$lang['arr_group_statistic_type_id'][107] = 			"total schedule items";


// REGISTRATION TYPE -----------------------------------------------------
$lang['arr_registration_type'][1] = 					"automatic";
$lang['arr_registration_type'][2] = 					"approved";
$lang['arr_registration_type'][3] = 					"closed";


// GROUP MEMBER STATUS ---------------------------------------------------
$lang['arr_group_member_status'][1] = 					"barred";
$lang['arr_group_member_status'][2] = 					"pending";
$lang['arr_group_member_status'][3] = 					"active";


// GROUP MEMBER STATUS ---------------------------------------------------
$lang['arr_group_status'][1] = 							"inactive";
$lang['arr_group_status'][2] = 							"hold";
$lang['arr_group_status'][3] = 							"pending";
$lang['arr_group_status'][4] = 							"active";


// GROUP VISIBILITY ---------------------------------------------------
$lang['arr_group_visibility'][1] = 						"visible";
$lang['arr_group_visibility'][2] = 						"hidden";

?>
